==> dev-plugin-android-0.0.38-sources.jar: com/zoyi/channel/plugin/android/ChannelView.java <==
package com.zoyi.channel.plugin.android;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Color;
import android.os.Build;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.activity.userchat_list.UserChatListActivity;
import com.zoyi.channel.plugin.android.event.BadgeBus;
import com.zoyi.channel.plugin.android.event.CommandBus;
import com.zoyi.channel.plugin.android.event.PushBus;
import com.zoyi.channel.plugin.android.event.RxBus;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.model.rest.Plugin;
import com.zoyi.channel.plugin.android.model.rest.ProfileEntity;
import com.zoyi.channel.plugin.android.model.rest.UserChat;
import com.zoyi.channel.plugin.android.util.AlarmCenter;
import com.zoyi.channel.plugin.android.util.CompareUtils;
import com.zoyi.channel.plugin.android.util.IntentUtils;
import com.zoyi.channel.plugin.android.util.ResUtils;
import com.zoyi.channel.plugin.android.util.Utils;
import com.zoyi.channel.plugin.android.view.external.fab.FloatingActionButton;
import com.zoyi.channel.plugin.android.view.handler.SimpleAnimationListener;
import com.zoyi.channel.plugin.android.view.layout.AvatarLayout;
import com.zoyi.rx.Subscription;
import com.zoyi.rx.android.schedulers.AndroidSchedulers;
import com.zoyi.rx.functions.Action1;

/**
 * Created by mika on 2017. 1. 24..
 */
public class ChannelView extends RelativeLayout {
  public static final int TOP_LEFT = 0;
  public static final int TOP_RIGHT = 1;
  public static final int BOTTOM_LEFT = 2;
  public static final int BOTTOM_RIGHT = 3;

  private int gravity;
  private int topMargin, bottomMargin, leftMargin, rightMargin;

  private View pushLayout;
  private AvatarLayout avatarLayout;
  private TextView textName, textMessage;
  private View fabLayout;
  private TextView badge;
  private FloatingActionButton fab;

  private Context context;
  private Animation pushAnimation;
  private Subscription subscription;
  private UserChat userChat;

  public ChannelView(Context context) {
    super(context);
    init(context, null);
  }

  public ChannelView(Context context, AttributeSet attrs) {
    super(context, attrs);
    init(context, attrs);
  }

  public ChannelView(Context context, AttributeSet attrs, int defStyleAttr) {
    super(context, attrs, defStyleAttr);
    init(context, attrs);
  }

  private void init(final Context context, AttributeSet attrs) {
    this.context = context;

    View view = LayoutInflater.from(context).inflate(R.layout.ch_plugin_layout_channel_view, this);
    fabLayout = view.findViewById(R.id.fab_layout);
    badge = (TextView) view.findViewById(R.id.text_badge);
    fab = (FloatingActionButton) view.findViewById(R.id.fab);
    fab.setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        ChannelPlugin.launch(ChannelView.this.context);
      }
    });

    int defaultMargin = context.getResources().getDimensionPixelSize(R.dimen.ch_default_channel_button_margin);
    final TypedArray a = getContext().obtainStyledAttributes(attrs, R.styleable.ChannelView, 0, 0);
    try {
      gravity = a.getInteger(R.styleable.ChannelView_channel_button_gravity, BOTTOM_RIGHT);

      topMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_top_margin, defaultMargin);
      bottomMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_bottom_margin, defaultMargin);
      leftMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_left_margin, defaultMargin);
      rightMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_right_margin, defaultMargin);

      setTopMargin(topMargin);
      setBottomMargin(bottomMargin);
      setLeftMargin(leftMargin);
      setRightMargin(rightMargin);

      setButtonGravity(gravity);
    } finally {
      if (a != null) {
        a.recycle();
      }
    }

    pushLayout = view.findViewById(R.id.push_layout);
    avatarLayout = (AvatarLayout) view.findViewById(R.id.push_avatar);
    textName = (TextView) view.findViewById(R.id.push_name);
    textMessage = (TextView) view.findViewById(R.id.push_message);

    pushAnimation = AnimationUtils.loadAnimation(getContext(), R.anim.ch_plugin_push);
    pushAnimation.setAnimationListener(new SimpleAnimationListener() {
      @Override
      public void onAnimationStart(Animation animation) {
        pushLayout.setVisibility(VISIBLE);
      }

      @Override
      public void onAnimationEnd(Animation animation) {
        hidePush();
      }
    });

    view.findViewById(R.id.iv_push_close).setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        hidePush();
      }
    });

    pushLayout.setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        String chatId = userChat != null ? userChat.getId() : null;
        IntentUtils.setNextActivity(context, UserChatListActivity.class)
            .putExtra(Const.EXTRA_CHAT_ID, chatId)
            .startActivity();
      }
    });
  }

  public void setButtonGravity(int gravity) {
    if (!CompareUtils.exists(gravity, TOP_LEFT, TOP_RIGHT, BOTTOM_LEFT, BOTTOM_RIGHT)) {
      return;
    }

    this.gravity = gravity;
    LayoutParams params = (LayoutParams) fabLayout.getLayoutParams();

    switch (gravity) {
      case TOP_LEFT:
      case TOP_RIGHT:
        params.addRule(RelativeLayout.ALIGN_PARENT_TOP);
        params.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM, 0);
        break;

      case BOTTOM_LEFT:
      case BOTTOM_RIGHT:
        params.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM);
        params.addRule(RelativeLayout.ALIGN_PARENT_TOP, 0);
        break;
    }

    switch (gravity) {
      case TOP_LEFT:
      case BOTTOM_LEFT:
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
          params.addRule(RelativeLayout.ALIGN_PARENT_START);
          params.addRule(RelativeLayout.ALIGN_PARENT_END, 0);
        }
        params.addRule(RelativeLayout.ALIGN_PARENT_LEFT);
        params.addRule(RelativeLayout.ALIGN_PARENT_RIGHT, 0);
        break;

      case TOP_RIGHT:
      case BOTTOM_RIGHT:
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
          params.addRule(RelativeLayout.ALIGN_PARENT_START, 0);
          params.addRule(RelativeLayout.ALIGN_PARENT_END);
        }
        params.addRule(RelativeLayout.ALIGN_PARENT_LEFT, 0);
        params.addRule(RelativeLayout.ALIGN_PARENT_RIGHT);
        break;
    }

    fabLayout.setLayoutParams(params);
    fabLayout.requestLayout();
    badge.bringToFront();
  }

  public void setTopMargin(int topMargin) {
    this.topMargin = topMargin;
    refreshSize();
  }

  public void setBottomMargin(int bottomMargin) {
    this.bottomMargin = bottomMargin;
    refreshSize();
  }

  public void setLeftMargin(int leftMargin) {
    this.leftMargin = leftMargin;
    refreshSize();
  }

  public void setRightMargin(int rightMargin) {
    this.rightMargin = rightMargin;
    refreshSize();
  }

  private void refreshSize() {
    LayoutParams params = (LayoutParams) fabLayout.getLayoutParams();

    switch (gravity) {
      case TOP_LEFT:
        params.setMargins(leftMargin, topMargin, 0, 0);
        break;

      case TOP_RIGHT:
        params.setMargins(0, topMargin, rightMargin, 0);
        break;

      case BOTTOM_LEFT:
        params.setMargins(leftMargin, 0, 0, bottomMargin);
        break;

      case BOTTOM_RIGHT:
        params.setMargins(0, 0, rightMargin, bottomMargin);
        break;
    }

    fabLayout.setLayoutParams(params);
    fabLayout.requestLayout();
    badge.bringToFront();
  }

  @Override
  protected void onAttachedToWindow() {
    super.onAttachedToWindow();
    subscription = RxBus.observable()
        .onBackpressureBuffer()
        .observeOn(AndroidSchedulers.mainThread())
        .subscribe(new Action1<Object>() {
          @Override
          public void call(Object o) {
            if (o instanceof CommandBus) {
              CommandBus commandBus = (CommandBus) o;
              switch (commandBus.getCommand()) {
                case CHECKED_IN:
                  if (commandBus.getObject() != null && commandBus.getObject() instanceof Plugin) {
                    checkedIn((Plugin) commandBus.getObject());
                  }
                  break;

                case CHECKED_OUT:
                  checkedOut();
                  break;
              }
            }

            if (o instanceof PushBus) {
              if (!ChannelStore.isMainRunning()) {
                PushBus pushBus = (PushBus) o;
                showPush(pushBus.getProfileEntity(), pushBus.getMessage(), pushBus.getUserChat());
              }
            }

            if (o instanceof BadgeBus) {
              setBadge(((BadgeBus) o).getCount());
            }
          }
        });
    if (ChannelStore.getPlugin() != null) {
      checkedIn(ChannelStore.getPlugin());
    }
  }

  @Override
  protected void onDetachedFromWindow() {
    super.onDetachedFromWindow();
    if (subscription != null && !subscription.isUnsubscribed()) {
      subscription.unsubscribe();
    }
  }

  private void checkedIn(Plugin plugin) {
    if (plugin != null) {
      setVisibility(VISIBLE);

      fab.setColorNormal(plugin.getBackgroundColor());
      fab.setColorPressed(Utils.addBlackMask(plugin.getBackgroundColor()));
      fab.setColorRipple(Color.WHITE);
      fab.setImageResource(
          plugin.getTextColor() == Color.BLACK
              ? R.drawable.ch_plugin_balloon_black
              : R.drawable.ch_plugin_balloon_white);

      refreshCount();

      fabLayout.setVisibility(VISIBLE);
    }
  }

  public void refreshCount() {
    setBadge(ChannelStore.getCount());
  }

  private void setBadge(int count) {
    if (count <= 0) {
      badge.setVisibility(GONE);
    } else {
      badge.setVisibility(VISIBLE);
      badge.setText(Utils.getCount(count, true));
    }
  }

  private void checkedOut() {
    setVisibility(GONE);
  }

  private void showPush(ProfileEntity person, String message, UserChat userChat) {
    this.userChat = userChat;

    if (userChat.isStateCompleted()) {
      avatarLayout.set(R.drawable.ch_plugin_review_avatar);
      textName.setText(R.string.ch_review_title_preview);
      textMessage.setText(R.string.ch_review_require_preview);
    } else {
      avatarLayout.set(person);
      avatarLayout.setTextSize(14);

      if (person != null && person.getName() != null) {
        textName.setText(person.getName());
      } else {
        textName.setText(ResUtils.getString(context, "ch.unknown"));
      }
      textMessage.setText(message);
    }

    pushLayout.setVisibility(VISIBLE);
    pushLayout.startAnimation(pushAnimation);

    AlarmCenter.alarm(context);
  }

  private void hidePush() {
    this.userChat = null;

    pushLayout.clearAnimation();
    pushLayout.setVisibility(GONE);
  }
}

==> dev-plugin-android-0.0.43-sources.jar: com/zoyi/channel/plugin/android/ChannelView.java <==
package com.zoyi.channel.plugin.android;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Color;
import android.os.Build;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.activity.userchat_list.UserChatListActivity;
import com.zoyi.channel.plugin.android.event.BadgeBus;
import com.zoyi.channel.plugin.android.event.CommandBus;
import com.zoyi.channel.plugin.android.event.PushBus;
import com.zoyi.channel.plugin.android.event.RxBus;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.global.PrefSupervisor;
import com.zoyi.channel.plugin.android.model.rest.Plugin;
import com.zoyi.channel.plugin.android.model.rest.ProfileEntity;
import com.zoyi.channel.plugin.android.model.rest.UserChat;
import com.zoyi.channel.plugin.android.util.AlarmCenter;
import com.zoyi.channel.plugin.android.util.CompareUtils;
import com.zoyi.channel.plugin.android.util.IntentUtils;
import com.zoyi.channel.plugin.android.util.ResUtils;
import com.zoyi.channel.plugin.android.util.Utils;
import com.zoyi.channel.plugin.android.view.external.fab.FloatingActionButton;
import com.zoyi.channel.plugin.android.view.handler.SimpleAnimationListener;
import com.zoyi.channel.plugin.android.view.layout.AvatarLayout;
import com.zoyi.rx.Subscription;
import com.zoyi.rx.android.schedulers.AndroidSchedulers;
import com.zoyi.rx.functions.Action1;

/**
 * Created by mika on 2017. 1. 24..
 */
public class ChannelView extends RelativeLayout {
  public static final int TOP_LEFT = 0;
  public static final int TOP_RIGHT = 1;
  public static final int BOTTOM_LEFT = 2;
  public static final int BOTTOM_RIGHT = 3;

  private int gravity;
  private int topMargin, bottomMargin, leftMargin, rightMargin;

  private View pushLayout;
  private AvatarLayout avatarLayout;
  private View reviewAvatar;
  private TextView textName, textMessage;
  private View fabLayout;
  private TextView badge;
  private FloatingActionButton fab;

  private Context context;
  private Animation pushAnimation;
  private Subscription subscription;
  private UserChat userChat;

  public ChannelView(Context context) {
    super(context);
    init(context, null);
  }

  public ChannelView(Context context, AttributeSet attrs) {
    super(context, attrs);
    init(context, attrs);
  }

  public ChannelView(Context context, AttributeSet attrs, int defStyleAttr) {
    super(context, attrs, defStyleAttr);
    init(context, attrs);
  }

  private void init(final Context context, AttributeSet attrs) {
    this.context = context;

    View view = LayoutInflater.from(context).inflate(R.layout.ch_plugin_layout_channel_view, this);
    fabLayout = view.findViewById(R.id.fab_layout);
    badge = (TextView) view.findViewById(R.id.text_badge);
    fab = (FloatingActionButton) view.findViewById(R.id.fab);
    fab.setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        ChannelPlugin.launch(ChannelView.this.context);
      }
    });

    int defaultMargin = context.getResources().getDimensionPixelSize(R.dimen.ch_default_channel_button_margin);
    final TypedArray a = getContext().obtainStyledAttributes(attrs, R.styleable.ChannelView, 0, 0);
    try {
      gravity = a.getInteger(R.styleable.ChannelView_channel_button_gravity, BOTTOM_RIGHT);

      topMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_top_margin, defaultMargin);
      bottomMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_bottom_margin, defaultMargin);
      leftMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_left_margin, defaultMargin);
      rightMargin = a.getDimensionPixelSize(R.styleable.ChannelView_channel_button_right_margin, defaultMargin);

      setTopMargin(topMargin);
      setBottomMargin(bottomMargin);
      setLeftMargin(leftMargin);
      setRightMargin(rightMargin);

      setButtonGravity(gravity);
    } finally {
      if (a != null) {
        a.recycle();
      }
    }

    pushLayout = view.findViewById(R.id.push_layout);
    avatarLayout = (AvatarLayout) view.findViewById(R.id.push_avatar);
    reviewAvatar = view.findViewById(R.id.iv_review_avatar);
    textName = (TextView) view.findViewById(R.id.push_name);
    textMessage = (TextView) view.findViewById(R.id.push_message);

    pushAnimation = AnimationUtils.loadAnimation(getContext(), R.anim.ch_plugin_push);
    pushAnimation.setAnimationListener(new SimpleAnimationListener() {
      @Override
      public void onAnimationStart(Animation animation) {
        pushLayout.setVisibility(VISIBLE);
      }

      @Override
      public void onAnimationEnd(Animation animation) {
        hidePush();
      }
    });

    view.findViewById(R.id.iv_push_close).setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        hidePush();
      }
    });

    pushLayout.setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        String chatId = userChat != null ? userChat.getId() : null;
        IntentUtils.setNextActivity(context, UserChatListActivity.class)
            .putExtra(Const.EXTRA_CHAT_ID, chatId)
            .startActivity();
      }
    });
  }

  public void setButtonGravity(int gravity) {
    if (!CompareUtils.exists(gravity, TOP_LEFT, TOP_RIGHT, BOTTOM_LEFT, BOTTOM_RIGHT)) {
      return;
    }

    this.gravity = gravity;
    LayoutParams params = (LayoutParams) fabLayout.getLayoutParams();

    switch (gravity) {
      case TOP_LEFT:
      case TOP_RIGHT:
        params.addRule(RelativeLayout.ALIGN_PARENT_TOP);
        params.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM, 0);
        break;

      case BOTTOM_LEFT:
      case BOTTOM_RIGHT:
        params.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM);
        params.addRule(RelativeLayout.ALIGN_PARENT_TOP, 0);
        break;
    }

    switch (gravity) {
      case TOP_LEFT:
      case BOTTOM_LEFT:
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
          params.addRule(RelativeLayout.ALIGN_PARENT_START);
          params.addRule(RelativeLayout.ALIGN_PARENT_END, 0);
        }
        params.addRule(RelativeLayout.ALIGN_PARENT_LEFT);
        params.addRule(RelativeLayout.ALIGN_PARENT_RIGHT, 0);
        break;

      case TOP_RIGHT:
      case BOTTOM_RIGHT:
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
          params.addRule(RelativeLayout.ALIGN_PARENT_START, 0);
          params.addRule(RelativeLayout.ALIGN_PARENT_END);
        }
        params.addRule(RelativeLayout.ALIGN_PARENT_LEFT, 0);
        params.addRule(RelativeLayout.ALIGN_PARENT_RIGHT);
        break;
    }

    fabLayout.setLayoutParams(params);
    fabLayout.requestLayout();
    badge.bringToFront();
  }

  public void setTopMargin(int topMargin) {
    this.topMargin = topMargin;
    refreshSize();
  }

  public void setBottomMargin(int bottomMargin) {
    this.bottomMargin = bottomMargin;
    refreshSize();
  }

  public void setLeftMargin(int leftMargin) {
    this.leftMargin = leftMargin;
    refreshSize();
  }

  public void setRightMargin(int rightMargin) {
    this.rightMargin = rightMargin;
    refreshSize();
  }

  private void refreshSize() {
    LayoutParams params = (LayoutParams) fabLayout.getLayoutParams();

    switch (gravity) {
      case TOP_LEFT:
        params.setMargins(leftMargin, topMargin, 0, 0);
        break;

      case TOP_RIGHT:
        params.setMargins(0, topMargin, rightMargin, 0);
        break;

      case BOTTOM_LEFT:
        params.setMargins(leftMargin, 0, 0, bottomMargin);
        break;

      case BOTTOM_RIGHT:
        params.setMargins(0, 0, rightMargin, bottomMargin);
        break;
    }

    fabLayout.setLayoutParams(params);
    fabLayout.requestLayout();
    badge.bringToFront();
  }

  @Override
  protected void onAttachedToWindow() {
    super.onAttachedToWindow();
    subscription = RxBus.observable()
        .onBackpressureBuffer()
        .observeOn(AndroidSchedulers.mainThread())
        .subscribe(new Action1<Object>() {
          @Override
          public void call(Object o) {
            if (o instanceof CommandBus) {
              CommandBus commandBus = (CommandBus) o;
              switch (commandBus.getCommand()) {
                case CHECKED_IN:
                  if (commandBus.getObject() != null && commandBus.getObject() instanceof Plugin) {
                    checkedIn((Plugin) commandBus.getObject());
                  }
                  break;

                case CHECKED_OUT:
                  checkedOut();
                  break;
              }
            }

            if (o instanceof PushBus) {
              if (!ChannelStore.isMainRunning()) {
                PushBus pushBus = (PushBus) o;
                showPush(pushBus.getProfileEntity(), pushBus.getMessage(), pushBus.getUserChat());
              }
            }

            if (o instanceof BadgeBus) {
              setBadge(((BadgeBus) o).getCount());
            }
          }
        });
    if (ChannelStore.getPlugin() != null) {
      checkedIn(ChannelStore.getPlugin());
    }
  }

  @Override
  protected void onDetachedFromWindow() {
    super.onDetachedFromWindow();
    if (subscription != null && !subscription.isUnsubscribed()) {
      subscription.unsubscribe();
    }
  }

  private void checkedIn(Plugin plugin) {
    if (plugin != null) {
      setVisibility(VISIBLE);

      fab.setColorNormal(plugin.getBackgroundColor());
      fab.setColorPressed(Utils.addBlackMask(plugin.getBackgroundColor()));
      fab.setColorRipple(Color.WHITE);
      fab.setImageResource(
          plugin.getTextColor() == Color.BLACK
              ? R.drawable.ch_plugin_balloon_black
              : R.drawable.ch_plugin_balloon_white);

      refreshCount();

      fabLayout.setVisibility(VISIBLE);
    }
  }

  public void refreshCount() {
    setBadge(ChannelStore.getCount());
  }

  private void setBadge(int count) {
    if (count <= 0) {
      badge.setVisibility(GONE);
    } else {
      badge.setVisibility(VISIBLE);
      badge.setText(Utils.getCount(count, true));
    }
  }

  private void checkedOut() {
    setVisibility(GONE);
  }

  private void showPush(ProfileEntity person, String message, UserChat userChat) {
    this.userChat = userChat;

    if (userChat.isStateCompleted()) {
      avatarLayout.setVisibility(View.GONE);
      reviewAvatar.setVisibility(View.VISIBLE);

      textName.setText(R.string.ch_review_title_preview);
      textMessage.setText(R.string.ch_review_require_preview);
    } else {
      reviewAvatar.setVisibility(View.GONE);
      avatarLayout.setVisibility(View.VISIBLE);
      avatarLayout.set(person);
      avatarLayout.setTextSize(14);

      if (person != null && person.getName() != null) {
        textName.setText(person.getName());
      } else {
        textName.setText(ResUtils.getString(context, "ch.unknown"));
      }
      textMessage.setText(message);
    }

    pushLayout.setVisibility(VISIBLE);
    pushLayout.startAnimation(pushAnimation);

    if (PrefSupervisor.isEnabledPushAlarm(context)) {
      AlarmCenter.alarm(context);
    }
  }

  private void hidePush() {
    this.userChat = null;

    pushLayout.clearAnimation();
    pushLayout.setVisibility(GONE);
  }
}
